@@ -36,7 +36,10 @@ from .controls import (
     plot_sequences,
     plot_smooth_controls,
 )
-from .cost_history import plot_cost_history
+from .cost_histories import (
+    plot_cost_histories,
+    plot_cost_history,
+)
 from .filter_functions import plot_filter_functions
 from .histogram import plot_bitstring_probabilities_histogram
 from .populations import plot_populations
@@ -54,6 +57,7 @@ __all__ = [
     "get_qctrl_style",
     "plot_confidence_ellipses",
     "plot_controls",
+    "plot_cost_histories",
     "plot_cost_history",
     "plot_filter_functions",
     "plot_populations",
@@ -63,4 +67,4 @@ __all__ = [
     "plot_wigner_function",
 ]
 
-__version__ = "4.3.1"
+__version__ = "4.5.0"
