@@ -17,6 +17,7 @@ Functions for plotting control pulses.
 
 from __future__ import annotations
 
+import warnings
 from collections import namedtuple
 from typing import Any
 
@@ -228,6 +229,7 @@ def plot_controls(
     axes_list[-1].set_xlabel(f"Time ({time_prefix}s)")
 
 
+# Deprecated 2023/02/09.
 @qctrl_style()
 @figure_as_kwarg_only
 def plot_smooth_controls(
@@ -241,6 +243,8 @@ def plot_smooth_controls(
     """
     Create a plot of the specified smooth controls.
 
+    This function will be removed in the future. Please use `plot_controls` instead.
+
     Parameters
     ----------
     controls : dict
@@ -286,6 +290,12 @@ def plot_smooth_controls(
         }
     """
 
+    warnings.warn(
+        "The function `plot_smooth_controls` will be removed in the future. "
+        "Please use `plot_controls` instead.",
+        FutureWarning,
+    )
+
     plots_data: list[Any] = []
     for name, control in controls.items():
         # Process each control depending whether it's passed as a list of samples...
@@ -316,11 +326,11 @@ def plot_smooth_controls(
     for axes, plot_data in zip(axes_list, plots_data):
         # Pad with leading and trailing zeros, to indicate that the pulse is zero outside the plot
         # domain.
-        times = np.pad(plot_data.xdata, ((1, 1)), "edge") / time_scaling
-        values_arr = np.pad(plot_data.values, ((1, 1)), "constant")
+        plot_times = np.pad(plot_data.xdata, ((1, 1)), "edge") / time_scaling
+        values_arr = np.pad(np.asarray(plot_data.values), ((1, 1)), "constant")
 
-        axes.plot(times, values_arr, linewidth=2)
-        axes.fill(times, values_arr, alpha=0.3)
+        axes.plot(plot_times, values_arr, linewidth=2)
+        axes.fill(plot_times, values_arr, alpha=0.3)
 
         axes.axhline(y=0, linewidth=1, zorder=-1)
 
