@@ -24,11 +24,7 @@ from qctrlcommons.preconditions import (
     check_argument_non_negative_scalar,
 )
 
-from .style import (
-    FIG_HEIGHT,
-    FIG_WIDTH,
-    qctrl_style,
-)
+from .style import qctrl_style
 from .utils import figure_as_kwarg_only
 
 
@@ -93,7 +89,7 @@ def plot_bitstring_probabilities_histogram(
     display_all_bitstrings: bool = False,
     *,
     figure: plt.Figure,
-) -> None:
+):
     """
     Create a histogram of the specified counts.
 
@@ -127,9 +123,6 @@ def plot_bitstring_probabilities_histogram(
         # Sort the bitstring labels.
         sorted_bitstrings = sorted(set().union(*list(bitstring_counts.values())))
 
-    figure.set_figwidth(FIG_WIDTH)
-    figure.set_figheight(FIG_HEIGHT)
-
     axes = figure.subplots(nrows=1, ncols=1)
 
     default_bar_width = 0.8
