@@ -23,11 +23,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 from qctrlcommons.preconditions import check_argument
 
-from .style import (
-    FIG_HEIGHT,
-    FIG_WIDTH,
-    qctrl_style,
-)
+from .style import qctrl_style
 from .utils import (
     figure_as_kwarg_only,
     get_units,
@@ -59,9 +55,6 @@ def plot_populations(
 
     population_data = _create_population_data(sample_times, populations)
 
-    figure.set_figwidth(FIG_WIDTH)
-    figure.set_figheight(FIG_HEIGHT)
-
     axes = figure.subplots(nrows=1, ncols=1)
 
     scale, prefix = get_units(sample_times)
